#
# spec file for package octave-forge-instrument-control
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define octpkg  instrument-control
Name:           octave-forge-%{octpkg}
Version:        0.9.1
Release:        1.2
Summary:        Instrument Control for Octave
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://gnu-octave.github.io/packages/%{octpkg}/
Source0:        https://downloads.sourceforge.net/octave/%{octpkg}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM instrument-control-no-return-in-nonvoid-function.patch badshah400@gmail.com -- Fix non-void functions not returning data typically at the end of an if-elseif-else block.
Patch0:         instrument-control-no-return-in-nonvoid-function.patch
BuildRequires:  gcc-c++
BuildRequires:  hdf5-devel
BuildRequires:  octave-devel >= 4.0.0
Requires:       octave-cli >= 4.0.0

%description
Low level I/O functions for serial, i2c, parallel, tcp, gpib, vxi11 and usbtmc interfaces.
This is part of the Octave-Forge project.

%prep
%setup -q -c %{name}-%{version}
pushd %{octpkg}-%{version}
%patch0 -p2
popd
%octave_pkg_src

%build
%octave_pkg_build

%install
%octave_pkg_install

%check
%octave_pkg_test

%post
%octave --eval "pkg rebuild"

%postun
%octave --eval "pkg rebuild"

%files
%{octpackages_dir}/%{octpkg}-%{version}
%{octlib_dir}/%{octpkg}-%{version}

%changelog
* Mon Oct 30 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update URL to point to 'https://gnu-octave.github.io/packages/'
* Mon Oct 16 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to verion 0.9.1:
  * bugfix modbus portnumber input.
- Changes from version 0.9.0:
  * General updates to support Octave 8+
  * readline: updated docs, minor bug fixes
  * VXI11: add instrument name support
  * UDPPORT: add new writeline function, buffer reading
  * UDP: buffer reading
* Thu Sep 15 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 0.8.0:
  * MODBUS: Added new modbus class
  * TCPSERVER: Added new tcpserver class
  * minor bug fixes in configure
  * added QT help doc generation
  * updates to package documentation
  * added common functions:
    writeline
    readline
    readbinblock
    writebinblock
    writeread
  * TCPCLIENT: bugfix read when used with no size parameter
  * UDPPORT: bugfix read when used with no size parameter
  * Min octave version is now 4.0
* Mon Feb 21 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.7.1:
  * General updates to support Octave 7+
  * Updated common functions:
  - fread - set correct size of uint16
  - fprintf - fix else for multiple args
* Sat Mar 13 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.7.0:
  * Update get function for instrument controls to not use cellfun
    (Bug #59581)
  * UDPPORT: Added new udpport class
  * TCPCLIENT:  Added new tcpclient class
  * SERIALPORT: update property access to proper case usage
* Sat Oct 31 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.6.0:
  * SPI: added new spi object and functions.
  * TCP:
  - added tcpclient, depreciated tcpip.
  - added methods flush, read, write.
  * UDP: added methods flush, read, write.
* Thu May  7 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 0.5.0:
  * General updates to support Octave 6+
  * Added common functions
    + flushinput
    + flushoutput
    + instrhelp
  * SERIALPORT: added new serialport object and functions
  * SERIAL: use extended win32 serial name for comports so > 10 work.
    + New serial functions:
  * serialbreak
    + Added overload functions for:
  * fprintf
  * fread
  * fwrite
    + Added properties:
  * port
    + Added .property access
  * UDP: add .property access to the object
    + Added properties:
  * localhost
    + Updates property timeout to be seconds
    + Updated udp constructor to be closer to matlab compatible
  * TCP: add .property access to the object
    + Updates property timeout to be seconds
    + Updated constructor to be closer to matlab compatible
  * I2C:
    + Implement object properties
    + Added overload functions for:
  * fread
  * fwrite
  * get
  * set
  * PARALLEL:
    + Added overload functions for:
  * fclose
  * fopen
  * fread
  * fwrite
  * USBTMC:
    + Added overload functions for:
  * fread
  * fwrite
  * VXI11:
    + Added overload functions for:
  * fread
  * fwrite
  * insthwinfo: updated to show i2c ports
  * added toolkit manual
* Tue Nov 26 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 0.4.0:
  * SERIAL: added 'status', 'bytesavailable', 'name' and 'type'
    properties, and the following functions:
    + seriallist
    + flushinput
    + flushoutput
  * UDP: added 'status' and 'bytesavailable' properties and the
    following functions:
    + flushinput
    + flushoutput
  * TCP: added properties to object, added overridden functions:
    + get
    + set
    + fprintf
    + fread
    + fwrite
    + flushinput
    + flushoutput
  * tcpip(): added wrapper to be matlab compatible(ish)
  * distribute rpc generated files
  * verify -M option will work on rpcgen
  * detect if rpc_error functions allow use of const inputs
  * prefer libtirpc over builtin rpc when detecting vxi11 functionality
  * add lock functions used on pkg load/unlock to lock .oct files
  * implemented instrhwinfo serial list for mac
* Wed Jun  6 2018 badshah400@gmail.com
- Update to version 0.3.1:
  * Updated build to allow install on octave 4.4
  * using polling rather than signal handling to break from
    instrument reads
  * insthwinfo() updated to show enabled modules
  * added initial builtin tests for each instrument
- Changes from version 0.3.0:
  * SERIAL: allow non standard baudrates in win32
  * TCP: new functions: resolvehost
  * UDP: new, interface, with, functions, for: udp, udp_timeout,
    udp_read, udp_write, udp_close, udp_demo
  * UDP overload functions for: fprintf, fread, fwrite, fclose,
    fopen, get, set
- Add patch:
  instrument-control-no-return-in-nonvoid-function.patch: Fix
  non-void functions not returning data typically at the end of an
  if-elseif-else block.
* Thu Nov 24 2016 dmitry_r@opensuse.org
- Update to version 0.2.3
  * New function: instrhwinfo
  * Bug fixes
* Sat Jun 11 2016 dmitry_r@opensuse.org
- Update to version 0.2.2
  * New function 'fread'
  * Bug fixes
* Thu Feb 26 2015 dmitry_r@opensuse.org
- Split from octave-forge package, version 0.2.1
